@@ -19,10 +19,22 @@ def approximate(**kwargs):
         is_first_call: bool = True
 
         @wraps(func)
-        def wrapper(point):
+        def wrapper(*wrapper_args):
+            # args must either contain the point to be analyzed
+            # or it must contain self (for class methods) and then the point
             nonlocal is_first_call
             nonlocal controller
             nonlocal estimator
+            if len(wrapper_args) < 1 or len(wrapper_args) > 2:
+                raise Exception(
+                    "The decorated function must have a single input which is a list of numbers, "
+                    + "self may also be present for non-static class methods, in such case self is "
+                    + "expected to be the first argument followed by the point and nothing"
+                )
+            if len(wrapper_args) == 1:
+                point = wrapper_args[0]
+            else:
+                point = wrapper_args[1]
             if is_first_call:
                 is_first_call = False
                 selected_model = globals().get(str(kwargs.get("estimator")) + "Model")
@@ -50,11 +62,12 @@ def approximate(**kwargs):
                 controller = controller(
                     func,
                     estimator,
+                    self_exact=None if len(wrapper_args) == 1 else wrapper_args[0],
                     **{
                         k[k.find("_") + 1 :]: v
                         for k, v in kwargs.items()
                         if k[: k.find("_")] == "controller"
-                    }
+                    },
                 )
 
             controller.compute_objective(
@@ -70,7 +83,13 @@ def approximate(**kwargs):
 
 class Movado:
     def __init__(self):
-        self.models = [model for model in globals().keys() if "Model" in model]
+        self.models = [
+            model.replace("Model", "")
+            for model in globals().keys()
+            if ("Model" in model) and len(model) > 5
+        ]
         self.controllers = [
-            controller for controller in globals().keys() if "Controller" in controller
+            controller.replace("Controller", "")
+            for controller in globals().keys()
+            if ("Controller" in controller) and len(controller) > 10
         ]
